@@ -1,4 +1,7 @@
+#ifndef FREQUENCES_H
+#define FREQUENCES_H
 #include <iostream>
 #include <QtCore>
 using namespace std;
 int frequentia (QString requete);
+#endif
