@@ -49,6 +49,7 @@
 
 // variables
 string uia;
+QString qsuia;
 int minRaritas; // degr minimum de raret permettant d'afficher la lemmatisation (de 0  5).
 bool morphologia; // autorise/interdit l'affichage des morphologies.
 bool syntaxis = true;
@@ -151,7 +152,7 @@ QString Editeur::lemmatiseTxt_expr (bool alpha)
 		else C.setPosition (tc2.position (), QTextCursor::KeepAnchor); 
 		P = new Phrase (C.selectedText ());
 		//emit (copie (P->analyse_et_lemmes ()));
-        QStringList * sl = P->analyse_et_lemmes ();
+        QStringList * sl = P->analyse_et_lemmes (minRaritas);
         QString l;
         for (int i=0;i<sl->size();i++) 
         {
@@ -189,7 +190,7 @@ void Editeur::mouseReleaseEvent (QMouseEvent *event)
     QPoint P = parentWidget()->mapFromGlobal(event->globalPos());
     QTextCursor C = cursorForPosition (P);
     QString mc = motCourant (C);
-    if (mc.isEmpty ()) return;
+    //if (QString(uia).isEmpty ()) return;
     QString ligne = QString::fromStdString (lemmatise (mc.toStdString ()));
     ligne.remove (QRegExp ("^\n+"));
     if (frequentia (prima (ligne)) < minRaritas)
@@ -292,12 +293,13 @@ fenestra::fenestra(QString url)
     magisterSum = getRights ();
     // chargement du lexique et du fichier d'exemple
     if (url.isEmpty ())
-        capsamInLatinum ( QString::fromStdString (uia + "lucretia.txt"));
+        capsamInLatinum ( qsuia + "lucretia.txt");
     else
         capsamInLatinum ( url);
-    // chargemen des lexiques fr et synt.
+    // chargement des lexiques fr et synt.
     gallice ();
-    lis_expr (QString::fromStdString (uia) + "expressions.fr");
+    //qDebug () << "uia :" << uia;
+    lis_expr (qsuia + "expressions.fr");
 
     // paramtrage de la recherche syntaxique ;  complter
     cree_texte ();
@@ -309,8 +311,8 @@ void fenestra::decollatino ()
 {
     QMessageBox::about(this, tr("De Collatino"),
             tr("COLLATINVS\nLinguae latinae lemmatizatio \n"
-               "Licenti GPL-3, (c) Yves Ouvrard, anno 2008 \n"
-               "Versio IX"));
+               "Licenti GPL, (c) Yves Ouvrard, anno 2009 \n"
+               "Versio IX.1"));
 }
 
 /**
@@ -683,11 +685,11 @@ void fenestra::inuenire_denuo ()
 void fenestra::auxilium ()
 {
    #ifdef Q_WS_X11
-    QFileInfo info (QString::fromStdString (uia + "doc/collatinus.html"));
+    QFileInfo info (qsuia + "doc/collatinus.html");
     QString html;
     if (info.exists ())
         html = "mozilla \"file://" + info.absoluteFilePath () + "\""; 
-    else html = "mozilla \"file:///usr/share/doc/collatinus/html/collatinus.html\"";
+    else html = "mozilla \"file:///usr/share/doc/collatinus/collatinus.html\"";
     QProcess processus;
     processus.startDetached (html);
     #else
@@ -730,6 +732,7 @@ void fenestra::magister ()
         dialogon D;
         D.ad_raritas (minRaritas);
         D.ad_morphologia (licetMorpho);
+	//qDebug () << "minraritas " << minRaritas << " morphologia " << morphologia;
         if (D.exec () == QDialog::Accepted)
         {
             minRaritas = D.raritas ();
@@ -749,9 +752,15 @@ bool fenestra::getLicetMorpho ()
 
 bool fenestra::getRights ()
 {
+    //qDebug () << "entre dans getRights";
+#ifdef Q_WS_WIN
+    QString uiaP = qsuia + "config"; 
+#else
     QString uiaP ("/etc/collatinus/config");
     if (!QFile::exists (uiaP))
-        uiaP = QString::fromStdString (uia + "config"); 
+        uiaP = qsuia + "config"; 
+#endif
+    // qDebug () << "uiap:" << uiaP;
     QFile fConf (uiaP);
     if (fConf.open (QFile::ReadOnly))
     {
@@ -777,7 +786,7 @@ bool fenestra::getRights ()
 
 void fenestra::setRights ()
 {
-    QFile fConf (QString::fromStdString (uia + "config"));
+    QFile fConf (qsuia + "config");
     if (fConf.open (QFile::WriteOnly))
     {
         QTextStream Ab (&fConf);
@@ -816,21 +825,25 @@ void fenestra::createActions ()
 
 int main( int argc, char **argv )
 {
-	uia = argv[0];
-	uia.erase (uia.length () - 10);
-	QFileInfo info (QString::fromStdString (uia) + "/lucretia.txt");
-	if (!info.exists ())
+    uia = argv[0];
+#ifdef Q_WS_WIN
+    uia.erase (uia.length () - 14);
+#else
+    uia.erase (uia.length () - 10);
+#endif
+    qsuia = QString::fromStdString (uia);
+    qDebug () << qsuia; 
+    if (!QFile::exists (qsuia + "lucretia.txt"))
     {
 #ifdef Q_WS_WIN
-      //uia.erase (uia.length () - 14);
-      uia = "C:\\Program Files\\collatinus\\";
+	uia = "C:\\Program Files\\collatinus\\";
 #else
-      uia = "/usr/share/collatinus9/";
-      //uia.erase (uia.length () - 10);
+	uia = "/usr/share/collatinus/";
 #endif
-	}
-	QApplication app(argc, argv);
-	fenestra f (argv [1]);
-	f.show();
-	return app.exec();
+	qsuia = QString::fromStdString (uia);
+    }
+    QApplication app(argc, argv);
+    fenestra f (argv [1]);
+    f.show();
+    return app.exec();
 }
