@@ -18,6 +18,7 @@
  *
  */
 
+#include "frequences.h"
 #include "syntaxe.h"
 #include <QFile>
 #include <QMessageBox>
@@ -287,7 +288,9 @@ int Mot::count_morphos ()
 
 QString Mot::getCanon (int i)
 {
-    return morphos[i]->getCanon ();
+    if (i <  morphos.size ())
+        return morphos[i]->getCanon ();
+    return "";
 }
 
 Morphos * Mot::getMorpho (int i)
@@ -355,6 +358,7 @@ Expression::Expression (QString n)
     {
         QStringList liste = eclats[ie].split ('.');
         Morphos * m = new Morphos (liste[1]);
+        // if (liste[0] == "res") qDebug () << "res trouvé : " << n;
         m->setCanon (liste[0]); 
         if (!liste[2].isEmpty ()) 
         {
@@ -442,13 +446,16 @@ Liste_expr::Liste_expr (QString f)
     }
 
     QTextStream in(&file);
-
-    while (!file.atEnd ())
+    QString lin;
+    lin = in.readLine ();
+    //while (!file.atEnd ())
+    while (!lin.isNull ())
     {
-        QString lin = in.readLine ().simplified ();
         Expression * E = new Expression (lin);
         // injection
         expressions.insert (E->lemme_noyau (), E); 
+        //qDebug () << lin;
+        lin = in.readLine ();
     }
 }
 
@@ -459,6 +466,7 @@ Liste_expr::~Liste_expr ()
 
 QList<Expression *> Liste_expr::expr_lemme (QString l)
 {
+    //qDebug () << "liste_expr (" << l << ")";
     return expressions.values (l);    
 }
 
@@ -563,6 +571,7 @@ void Phrase::cherche_expressions ()
        {
             // s'il n'est pas noyo potentiel, mot suivant
             QList<Expression *> le = LExpressions->expr_lemme (mot->getCanon (i));
+            //qDebug () << mot->getCanon (i) << " " << le.isEmpty ();
             if (le.isEmpty ()) continue;
             // ici, possibilité de renvoyer toute expression utilisant le mot
             // pour chaque expression potentielle
@@ -644,7 +653,7 @@ Expression * Phrase::expression_no (int n)
 	return NULL;
 }
 
-QStringList * Phrase::analyse_et_lemmes ()
+QStringList * Phrase::analyse_et_lemmes (int minRaritas)
 {
 	QStringList * retour = new QStringList ();
 	QString doc;
@@ -653,7 +662,10 @@ QStringList * Phrase::analyse_et_lemmes ()
 	for (int i = 0; i < mots.count (); i++)
 	{
 		 //ts << "\n" <<  mots[i]->get_lemme ();	
-		 retour->append (mots[i]->get_lemme ());
+         QString lemma (mots[i]->getCanon (0));
+         //qDebug () << lemma << " " << frequentia (lemma);
+         if (minRaritas <= frequentia (lemma))
+		     retour->append (mots[i]->get_lemme ());
 		 e = expression_no (i); 
 		 if (e != NULL) 
              retour->append  ("\n   " + QString (0x00B6) + " " + e->getNom () + " : " + e->getDoc ());
